**********
User Guide
**********

Our User Guide documents key concepts in detail.

New users may prefer to start with the gentle introduction in our
`Getting Started <../getting_started/index.html>`_ guide.

To see what can be done with Project, see our `Gallery
<../gallery/index.html>`_ of interesting examples.

Contents:

* `Annotating your Data <01-Annotating_Data.html>`_
   Core concepts when annotating your data with semantic metadata.

* `Customizing Plots <03-Customizing_Plots.html>`_
   Controlling the look and feel of the visual representation.
   
* `Responding to Events <11-Responding_to_Events.html>`_
   Allow your visualizations to respond to Python events using the 'streams' system.

* Etc...

.. toctree::
    :titlesonly:
    :hidden:
    :maxdepth: 2

    Annotating your Data <01-Annotating_Data>
    Customizing Plots <03-Customizing_Plots>
    Responding to Events <11-Responding_to_Events>
